package com.example.playertime;

import com.google.gson.*;
import java.io.*;
import java.nio.file.*;

public class ModConfig {
    private static final Gson GSON = new GsonBuilder().setPrettyPrinting().create();
    private final Path configPath;
    private int webPort = 60048;

    public ModConfig(Path configDir) {
        this.configPath = configDir.resolve("playertime-config.json");
        loadConfig();
    }

    private void loadConfig() {
        if (!Files.exists(configPath)) {
            saveConfig();
            return;
        }

        try (Reader reader = Files.newBufferedReader(configPath)) {
            JsonObject json = JsonParser.parseReader(reader).getAsJsonObject();
            if (json.has("webPort")) {
                webPort = json.get("webPort").getAsInt();
            }
        } catch (Exception e) {
            PlayerTimeMod.LOGGER.error("[在线时间] 加载配置失败", e);
        }
    }

    private void saveConfig() {
        JsonObject json = new JsonObject();
        json.addProperty("webPort", webPort);

        try {
            Files.createDirectories(configPath.getParent());
            try (Writer writer = Files.newBufferedWriter(configPath)) {
                GSON.toJson(json, writer);
            }
        } catch (Exception e) {
            PlayerTimeMod.LOGGER.error("[在线时间] 保存配置失败", e);
        }
    }

    public int getWebPort() {
        return webPort;
    }
}