package com.example.playertime;

import net.fabricmc.api.ModInitializer;
import net.fabricmc.fabric.api.event.lifecycle.v1.ServerLifecycleEvents;
import net.fabricmc.fabric.api.networking.v1.ServerPlayConnectionEvents;
import net.fabricmc.loader.api.FabricLoader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class PlayerTimeMod implements ModInitializer {
    public static final Logger LOGGER = LoggerFactory.getLogger("PlayerTimeTracker");
    private static PlayerTimeTracker timeTracker;
    private static WebServer webServer;
    private static ModConfig config;

    @Override
    public void onInitialize() {

        config = new ModConfig(FabricLoader.getInstance().getConfigDir());


        try {
            LOGGER.info("[在线时间] 初始化玩家在线时长视奸MOD");


            ServerLifecycleEvents.SERVER_STARTING.register(server -> {
                timeTracker = new PlayerTimeTracker(server);
                try {
                    webServer = new WebServer(timeTracker, config.getWebPort(), server); // 传入 MinecraftServer
                    webServer.start();
                    LOGGER.info("[在线时间] Web服务器在端口 " + config.getWebPort() + " 启动");
                } catch (Exception e) {
                    LOGGER.error("[在线时间] 无法启动Web服务器", e);
                }
            });

            ServerPlayConnectionEvents.JOIN.register((handler, sender, server) -> {
                if (timeTracker != null) {
                    timeTracker.onPlayerJoin(handler.player);
                }
            });

            ServerPlayConnectionEvents.DISCONNECT.register((handler, server) -> {
                if (timeTracker != null) {
                    timeTracker.onPlayerLeave(handler.player);
                }
            });

            ServerLifecycleEvents.SERVER_STOPPING.register(server -> {
                LOGGER.info("[在线时间] 服务器停止 - 保存数据");
                if (webServer != null) {
                    webServer.stop();
                }
                if (timeTracker != null) {
                    timeTracker.saveAll();
                }
            });

        } catch (Exception e) {
            LOGGER.error("[在线时间] Mod 初始化失败!", e);
            throw new RuntimeException("[在线时间] Mod 初始化失败", e);
        }
    }

    public static ModConfig getConfig() {
        return config;
    }



    public static PlayerTimeTracker getTimeTracker() {
        return timeTracker;
    }
}