document.addEventListener('DOMContentLoaded', function() {
    const refreshBtn = document.getElementById('refresh-btn');
    const themeToggle = document.getElementById('theme-toggle');
    const statsTable = document.getElementById('stats-table').getElementsByTagName('tbody')[0];
    const onlineCountEl = document.getElementById('online-count');
    const onlinePlayersEl = document.getElementById('online-players');
    const topPlayersEl = document.getElementById('top-players');

    // 初始化主题
    const savedTheme = localStorage.getItem('theme') || 'light';
    document.documentElement.setAttribute('data-theme', savedTheme);

    // 主题切换功能
    themeToggle.addEventListener('click', () => {
        const currentTheme = document.documentElement.getAttribute('data-theme');
        const newTheme = currentTheme === 'light' ? 'dark' : 'light';
        document.documentElement.setAttribute('data-theme', newTheme);
        localStorage.setItem('theme', newTheme);
    });

    loadAllData();

    refreshBtn.addEventListener('click', function() {
        refreshBtn.classList.add('loading');
        loadAllData();
        setTimeout(() => {
            refreshBtn.classList.remove('loading');
        }, 1000);
    });

    function loadAllData() {
        // 加载统计数据
        fetch('/api/stats')
            .then(response => response.json())
            .then(data => {
                updateTable(data);
            })
            .catch(error => {
                console.error('获取统计信息时出错：', error);
                showError('未能加载玩家统计信息。 检查控制台以获取详细信息');
            });

        // 加载在线状态数据
        fetch('/api/widget-data')
            .then(response => response.json())
            .then(data => {
                updateOnlineStatus(data);
            })
            .catch(error => {
                console.error('获取在线状态时出错：', error);
                showError('未能加载在线状态信息。 检查控制台以获取详细信息');
            });
    }

    function updateTable(statsData) {
        statsTable.innerHTML = '';

        Object.entries(statsData).forEach(([playerName, statString]) => {
            const row = statsTable.insertRow();

            const nameCell = row.insertCell(0);
            nameCell.textContent = playerName;

            const stats = {};
            statString.split(" | ").forEach(part => {
                const [label, value] = part.split(": ");
                stats[label.trim()] = value;
            });

            const totalCell = row.insertCell(1);
            totalCell.textContent = stats["总时长"];

            const thirtyCell = row.insertCell(2);
            thirtyCell.textContent = stats["30天"];

            const sevenCell = row.insertCell(3);
            sevenCell.textContent = stats["7天"];
        });
    }

    function updateOnlineStatus(data) {
        // 更新在线人数
        onlineCountEl.textContent = data.onlineCount;

        // 更新在线玩家列表
        onlinePlayersEl.innerHTML = '';
        if (data.whitelistPlayers && data.whitelistPlayers.length > 0) {
            data.whitelistPlayers.forEach(player => {
                const li = document.createElement('li');
                li.innerHTML = `
                    <span class="player-name">${player.name}</span>
                    <span class="player-time">${player.time}</span>
                `;
                onlinePlayersEl.appendChild(li);
            });
        } else {
            onlinePlayersEl.innerHTML = '<li>暂无在线玩家</li>';
        }

        // 更新时长前三玩家
        topPlayersEl.innerHTML = '';
        if (data.topPlayers && data.topPlayers.length > 0) {
            data.topPlayers.forEach(player => {
                const li = document.createElement('li');
                li.innerHTML = `
                    <span class="player-name">${player.name}</span>
                    <span class="player-time">${player.time}</span>
                `;
                topPlayersEl.appendChild(li);
            });
        } else {
            topPlayersEl.innerHTML = '<li>暂无数据</li>';
        }
    }

    function showError(message) {
        const errorEl = document.createElement('div');
        errorEl.className = 'error-message';
        errorEl.textContent = message;
        document.body.appendChild(errorEl);

        setTimeout(() => {
            errorEl.classList.add('show');
        }, 10);

        setTimeout(() => {
            errorEl.classList.remove('show');
            setTimeout(() => {
                document.body.removeChild(errorEl);
            }, 300);
        }, 5000);
    }

    function parseTime(timeStr) {
        const [hPart, mPart] = timeStr.split(' ');
        const hours = parseInt(hPart.replace('h', ''));
        const minutes = parseInt(mPart.replace('m', ''));
        return hours * 60 + minutes;
    }
});
